pub struct Suspect {
pub kind: DiagnosisKind,
pub score: u8,
pub confidence: Confidence,
pub evidence: Vec<String>,
pub next_checks: Vec<String>,
}Expand description
Evidence-ranked suspect produced by heuristic analysis.
Suspects are triage leads and should be validated with follow-up checks.
Fields
kind: DiagnosisKindRanked suspect category.
score: u8Relative ranking score in range 0..=100 (higher means stronger evidence).
confidence: ConfidenceScore-derived confidence bucket for triage prioritization.
evidence: Vec<String>Supporting evidence strings used to justify this suspect ranking.
next_checks: Vec<String>Recommended next checks to validate or falsify this suspect.